@@ -26,8 +26,8 @@ double art::gaussain_sigma;
 
 int main(int argc, char* argv[]){
     cout << "=============================================================================="<<endl;
-    cout << "                            ART (Q Version 1.3.1)                             "<<endl; 
-    cout << "   Copyright(c) 2008-2011, Weichun Huang, Jason Myers. All Rights Reserved.   "<<endl; 
+    cout << "                            ART (Q Version 1.3.6)                             "<<endl; 
+    cout << "   Copyright(c) 2008-2012, Weichun Huang, Jason Myers. All Rights Reserved.   "<<endl; 
     cout << "=============================================================================="<<endl<<endl;
 
     bool mask_n=true; 
@@ -290,7 +290,6 @@ int main(int argc, char* argv[]){
 
     empdist::set_err_prob();
     empdist qdist(qual_file1, qual_file2, sep_flag, read_len);
-
     int profile_size=qdist.qual_dist_first.size();
     int profile_size_2=qdist.qual_dist_second.size();
     if(sep_flag){
@@ -330,6 +329,8 @@ int main(int argc, char* argv[]){
 			    if(q_shift_up<0 && (-q_shift_up>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up; }
 		    }
+	    }
+	    for(size_t i=0; i<qdist.qual_dist_second.size(); i++){
 		    for(map<unsigned int, unsigned short>::iterator it=qdist.qual_dist_second[i].begin(); it!=qdist.qual_dist_second[i].end(); it++){
 			    if(q_shift_up_2<0 && (-q_shift_up_2>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up_2; }
@@ -342,6 +343,8 @@ int main(int argc, char* argv[]){
 			    if(q_shift_up<0 && (-q_shift_up>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up; }
 		    }
+	    }
+	    for(size_t i=0; i<qdist.a_qual_dist_second.size(); i++){
 		    for(map<unsigned int, unsigned short>::iterator it=qdist.a_qual_dist_second[i].begin(); it!=qdist.a_qual_dist_second[i].end(); it++){
 			    if(q_shift_up_2<0 && (-q_shift_up_2>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up_2; }
@@ -353,6 +356,8 @@ int main(int argc, char* argv[]){
 			    if(q_shift_up<0 && (-q_shift_up>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up; }
 		    }
+	    }
+	    for(size_t i=0; i<qdist.c_qual_dist_second.size(); i++){
 		    for(map<unsigned int, unsigned short>::iterator it=qdist.c_qual_dist_second[i].begin(); it!=qdist.c_qual_dist_second[i].end(); it++){
 			    if(q_shift_up_2<0 && (-q_shift_up_2>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up_2; }
@@ -364,6 +369,8 @@ int main(int argc, char* argv[]){
 			    if(q_shift_up<0 && (-q_shift_up>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up; }
 		    }
+	    }
+	    for(size_t i=0; i<qdist.g_qual_dist_second.size(); i++){
 		    for(map<unsigned int, unsigned short>::iterator it=qdist.g_qual_dist_second[i].begin(); it!=qdist.g_qual_dist_second[i].end(); it++){
 			    if(q_shift_up_2<0 && (-q_shift_up_2>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up_2; }
@@ -375,6 +382,8 @@ int main(int argc, char* argv[]){
 			    if(q_shift_up<0 && (-q_shift_up>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up; }
 		    }
+	    }
+	    for(size_t i=0; i<qdist.t_qual_dist_second.size(); i++){
 		    for(map<unsigned int, unsigned short>::iterator it=qdist.t_qual_dist_second[i].begin(); it!=qdist.t_qual_dist_second[i].end(); it++){
 			    if(q_shift_up_2<0 && (-q_shift_up_2>it->second)){ it->second=0; }
 			    else{ it->second+=q_shift_up_2; }
